@@ -31,10 +31,10 @@ class StreamApp(object):
         self.state_manager = None
         self.parallel_index = None
 
-    def loop_input_port(self, actor: Actor, input_ports: list) -> None:
+    def loop_input_port(self, actor: Actor) -> None:
         stream_names_imput_map = {}
         upstream_actors = []
-        for input_port in input_ports:
+        for input_port in actor.get_input_ports():
             stream_names_imput_map[input_port.channel] = input_port
             upstream_actors.append(input_port.upstream_actor)
         consumer_id = generate()
@@ -100,17 +100,17 @@ class StreamApp(object):
     '''
     处理SinkActor
     '''
-    def process_sink_actor(self, act: SinkActor, input_ports: list) -> None:
+    def process_sink_actor(self, act: SinkActor) -> None:
         act.begin()
-        self.process_actor_common(act, input_ports)
+        self.process_actor_common(act)
         act.end()
 
 
     '''
     Actor常规处理
     '''
-    def process_actor_common(self, actor: Actor, input_ports: list) -> None:
-        self.loop_input_port(actor, input_ports)
+    def process_actor_common(self, actor: Actor) -> None:
+        self.loop_input_port(actor)
 
 
     '''
@@ -305,10 +305,10 @@ class StreamApp(object):
         if isinstance(self.actor, SourceActor):
             self.process_source_actor(self.actor)
         elif isinstance(self.actor, SinkActor):
-            self.process_sink_actor(self.actor, input_ports)
+            self.process_sink_actor(self.actor)
         # 处理其他Actor(Compute Actor)
         else:
-            self.process_actor_common(input_ports)
+            self.process_actor_common(self.actor)
 
 
 # if __name__ == '__main__':
