@@ -1,7 +1,6 @@
 from cloudam_stream.core.ports.port import Port
 from cloudam_stream.core.payload import Message, Record
 from cloudam_stream.core.streams import RedisProducer
-import json
 from typing import TypeVar, Generic
 
 
@@ -49,7 +48,7 @@ class FloatOutputPort(OutputPort[float]):
     pass
 
 
-class JsonOutputPort(OutputPort[json]):
+class JsonOutputPort(OutputPort[dict]):
 
     pass
 
