@@ -1,6 +1,6 @@
 from loguru import logger
 
-from core.constants import actor_constant
+from cloudam_stream.core.constants import actor_constant
 
 
 class FlowStateUtils(object):
